@@ -8,5 +8,5 @@ mkdir -p "$1"
 
 # Copy stuff there.
 
-cp -r 75dpi 100dpi misc *.pl install.sh Makefile "$1"
+cp -r 75dpi 100dpi misc DEBIAN Changelog* *README* *.pl makedeb.sh version.sh install.sh "$1"
  
