@@ -3,7 +3,10 @@
 # Prepare a distribution registered with iso8859-5. # rawin-r.
 
 # Directory to prepare files in.
-targetdir="./xcyr-2.3-1251"
+
+. version.sh
+
+targetdir="./xcyr-$version-cp1251"
 
 # Prepare that directory.
 
@@ -25,18 +28,20 @@ perl -e 'while(<>){s/koi8-c/RAWIN-R/g;s/^koi/win/g;print if (/^win/);}' < misc/f
 
 # Transform the special font "koinil2.bdf"
 
-perl bdfrecode.pl -table=full.table -registry=RAWIN-R < misc/koinil2.bdf > $targetdir/misc/koinil2.bdf
+perl bdfrecode.pl -table=full.table -registry=RAWIN-R < misc/koinil2.bdf > $targetdir/misc/winnil2.bdf
 
 # Transform "Makefile" in the "misc" directory
 
 perl -e 'while(<>){s/koi/win/g;print;}' < misc/Makefile > "$targetdir"/misc/Makefile
 
-# Transform "install.sh" to install into "cyrillic-1251" by default
+# Transform "install.sh" to install into "cyrillic-cp1251" by default
+
+for a in version.sh DEBIAN/*
+do
+	cat "$a" | sed -e 's/xcyr/xcyr-cp1251/g;s/koi8c/cp1251/g' > "$targetdir"/"$a"
+done
+
+cat DEBIAN/control | sed -e 's/cyrillic-koi8c/cyrillic-cp1251/;s/old Russian/Cyrillic/;s/a special KOI8-C/the CP1251/;s/\(Description: .*\) KOI8-C encoding/\1 CP-1251 encoding/;s/xfntcyr/xnftcyr1251/;' > "$targetdir"/DEBIAN/control
 
-perl -e 'while(<>){s/(targetdir=.*cyrillic)/\1-1251/;print;}' < install.sh > "$targetdir"/install.sh
 
 echo Done.
-
-
-
-
