@@ -2,8 +2,10 @@
 
 # Prepare a distribution registered with iso8859-5.
 
+. version.sh
+
 # Directory to prepare files in.
-targetdir="./xcyr-2.3-iso"
+targetdir="./xcyr-$version-iso"
 
 # Prepare that directory.
 
@@ -25,7 +27,7 @@ perl -e 'while(<>){s/koi8-c/iso8859-5/g;s/^koi/iso/g;print if (/^iso/);}' < misc
 
 # Transform the special font "koinil2.bdf"
 
-perl bdfrecode.pl -table=full.table -registry=ISO8859-5 < misc/koinil2.bdf > $targetdir/misc/koinil2.bdf
+perl bdfrecode.pl -table=full.table -registry=ISO8859-5 < misc/koinil2.bdf > $targetdir/misc/isonil2.bdf
 
 # Transform "Makefile" in the "misc" directory
 
