@@ -2,8 +2,10 @@
 
 # Prepare a distribution registered with koi8-r.
 
+. version.sh
+
 # Directory to prepare xrus files in.
-targetdir="./xcyr-2.3-koi8r"
+targetdir="./xcyr-$version-koi8r"
 
 # Prepare that directory.
 
