@@ -2,8 +2,10 @@
 
 # Prepare a stripped-down xrus distribution.
 
+. version.sh
+
 # Directory to prepare xrus files in.
-targetdir="./xrus-2.3.5"
+targetdir="./xrus-$version"
 
 # Prepare that directory.
 
@@ -18,7 +20,7 @@ rm "$targetdir"/*.sh "$targetdir"/xcyr*
 echo Recoding fonts:
 for font in misc/*.bdf
 do
-    perl bdfrecode.pl -table=xcyr2xrus-f.txt -registry=KOI8-R < $font > $targetdir/$font
+    perl bdfrecode.pl -table=xcyr2xrus.txt -registry=KOI8-R < $font > $targetdir/$font
     echo "$font"
 done
 for font in 100dpi/*.bdf 75dpi/*.bdf
