@@ -2,8 +2,10 @@
 
 # Prepare a stripped-down xrus distribution.
 
+. version.sh
+
 # Directory to prepare xrus files in.
-targetdir="./xukr-2.3"
+targetdir="./xukr-$version"
 
 # Prepare that directory.
 
